@@ -150,7 +150,7 @@ typedef enum {
 typedef struct {
   char           timeStamp[32]; /* time stamp as a string       */
   amdmsSEVERITY  severity;      /* severity (see amdmsSEVERITY) */
-  char          *locFile;       /* filename                     */
+  const char    *locFile;       /* filename                     */
   int            locLine;       /* line number in file          */
   char           text[1024];    /* additional formatted text    */
 } amdmsEVENT;
@@ -635,12 +635,12 @@ extern "C" {
   void amdmsSupressLogMessages(int flag);
   void amdmsShowOnlyMessage(int flag);
   void amdmsSetSeverityLevel(amdmsSEVERITY level);
-  void amdmsFatal(char *file, int line, char *format, ...);
-  void amdmsError(char *file, int line, char *format, ...);
-  void amdmsWarning(char *file, int line, char *format, ...);
-  void amdmsNotice(char *file, int line, char *format, ...);
-  void amdmsInfo(char *file, int line, char *format, ...);
-  void amdmsDebug(char *file, int line, char *format, ...);
+  void amdmsFatal(const char *file, int line, const char *format, ...);
+  void amdmsError(const char *file, int line, const char *format, ...);
+  void amdmsWarning(const char *file, int line, const char *format, ...);
+  void amdmsNotice(const char *file, int line, const char *format, ...);
+  void amdmsInfo(const char *file, int line, const char *format, ...);
+  void amdmsDebug(const char *file, int line, const char *format, ...);
   extern int amdmsOnlyMessage;
   extern amdmsEVENT amdmsLastEvent;
 
