@@ -439,7 +439,7 @@ amdmsCOMPL amdmsCalcFlatfield(amdmsALGO_PROPERTIES_ENV *env)
   double                   *ye = NULL;
   int                       i;
   int                       iInput, nInputs;
-  int                       iPixel, nPixels;
+  int                       iPixel;
   int                       iHS;
   int                       iVS;
   int                       iX, iY;
@@ -447,7 +447,7 @@ amdmsCOMPL amdmsCalcFlatfield(amdmsALGO_PROPERTIES_ENV *env)
   amdmsPIXEL                 m, dummy;
 
   nInputs = env->env.inFiles.nNames;
-  nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
+  //nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
   /* create all fit environments */
   if (amdmsCreateRayFit(&fitRay) != amdmsSUCCESS) {
     return amdmsFAILURE;
@@ -562,7 +562,7 @@ amdmsCOMPL amdmsCalcFlatfield(amdmsALGO_PROPERTIES_ENV *env)
 amdmsCOMPL amdmsCalcConversionFactorAmberR(amdmsALGO_PROPERTIES_ENV *env, int rX, int rY, int rW, int rH)
 {
   int                        iInput, nInputs;
-  int                        iPixel, nPixels;
+  int                        iPixel;
   amdmsFIT_LINEAR_ENV       *fitRay = NULL;
   amdmsFIT_SMOOTH_DATA_ENV  *fitSmooth = NULL;
   double                    *x = NULL;
@@ -571,7 +571,7 @@ amdmsCOMPL amdmsCalcConversionFactorAmberR(amdmsALGO_PROPERTIES_ENV *env, int rX
   int                        iX, iY;
 
   nInputs = env->env.inFiles.nNames;
-  nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
+  //nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
   /* create all fit environments */
   if (amdmsCreateRayFit(&fitRay) != amdmsSUCCESS) {
     return amdmsFAILURE;
@@ -653,7 +653,7 @@ amdmsCOMPL amdmsCalcConversionFactorAmberR(amdmsALGO_PROPERTIES_ENV *env, int rX
 amdmsCOMPL amdmsCalcConversionFactorGlobalLineR(amdmsALGO_PROPERTIES_ENV *env, int rX, int rY, int rW, int rH)
 {
   int          iInput, nInputs;
-  int          iPixel, nPixels;
+  int          iPixel;
   int          iX, iY;
   int          n    = 0;
   double       x, y;
@@ -663,7 +663,7 @@ amdmsCOMPL amdmsCalcConversionFactorGlobalLineR(amdmsALGO_PROPERTIES_ENV *env, i
   double       syy  = 0.0;
   double       sxy  = 0.0;
   double       ssxx = 0.0;
-  double       ssyy = 0.0;
+  //double       ssyy = 0.0;
   double       ssxy = 0.0;
   double       xq   = 0.0;
   double       yq   = 0.0;
@@ -671,7 +671,7 @@ amdmsCOMPL amdmsCalcConversionFactorGlobalLineR(amdmsALGO_PROPERTIES_ENV *env, i
   amdmsPIXEL   cf;
 
   nInputs = env->env.inFiles.nNames;
-  nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
+  //nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
   /* calculate the conversion factor but use only the central part of the region */
   for (iY = 0; iY < rH/2; iY++) {
     iPixel = env->meanPixels[0].nx*(rY + rH/4 + iY) + rX + rW/4;
@@ -694,7 +694,7 @@ amdmsCOMPL amdmsCalcConversionFactorGlobalLineR(amdmsALGO_PROPERTIES_ENV *env, i
   xq = sx/(double)n;
   yq = sy/(double)n;
   ssxx = sxx - (double)n*xq*xq;
-  ssyy = syy - (double)n*yq*yq;
+  //ssyy = syy - (double)n*yq*yq;
   ssxy = sxy - (double)n*xq*yq;
   if (ssxx == 0.0) {
     amdmsWarning(__FILE__, __LINE__, "ssxx == 0.0");
@@ -718,7 +718,7 @@ amdmsCOMPL amdmsCalcConversionFactorCentralLineR(amdmsALGO_PROPERTIES_ENV *env,
   double                    *y = NULL;
   double                    *ye = NULL;
   int                        iInput, nInputs;
-  int                        iPixel, nPixels;
+  int                        iPixel;
   int                        iHS, iVS;
   int                        sX, sY, sWidth, sHeight;
   int                        iX, iY;
@@ -727,10 +727,10 @@ amdmsCOMPL amdmsCalcConversionFactorCentralLineR(amdmsALGO_PROPERTIES_ENV *env,
   double                     cfCount = 0.0;
   double                     cfHSum = 0.0;
   double                     cfHCount = 0.0;
-  amdmsPIXEL                 cf;
+  amdmsPIXEL                 cf = 1.0;
 
   nInputs = env->env.inFiles.nNames;
-  nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
+  //nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
   /* create all fit environments */
   if (amdmsCreatePolynomialFit(&fitCF, 1) != amdmsSUCCESS) {
     return amdmsFAILURE;
@@ -890,7 +890,7 @@ amdmsCOMPL amdmsCalcConversionFactorCentralLineR(amdmsALGO_PROPERTIES_ENV *env,
 amdmsCOMPL amdmsCalcConversionFactorLocalPairs(amdmsALGO_PROPERTIES_ENV *env)
 {
   int          iInput, nInputs;
-  int          iPixel, nPixels;
+  int          iPixel;
   int          iHS, iVS;
   int          sX, sY, sWidth, sHeight;
   int          iX, iY;
@@ -911,7 +911,7 @@ amdmsCOMPL amdmsCalcConversionFactorLocalPairs(amdmsALGO_PROPERTIES_ENV *env)
   int          vsW[amdmsMAX_STRIPES];
 
   nInputs = env->env.inFiles.nNames;
-  nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
+  //nPixels = env->meanPixels[0].nx*env->meanPixels[0].ny;
   if (amdmsAllocateData(&(env->cfmData), env->meanPixels[0].nx, env->meanPixels[0].ny) != amdmsSUCCESS) {
     return amdmsFAILURE;
   }
@@ -1026,7 +1026,7 @@ amdmsCOMPL amdmsCalcConversionFactorLocalPairs(amdmsALGO_PROPERTIES_ENV *env)
 
 amdmsCOMPL amdmsCalcConversionFactor(amdmsALGO_PROPERTIES_ENV *env)
 {
-  int             nInputs;
+  //int             nInputs;
   int             i;
   int             iHS, iVS;
   int             nx, ny;
@@ -1034,7 +1034,7 @@ amdmsCOMPL amdmsCalcConversionFactor(amdmsALGO_PROPERTIES_ENV *env)
   amdmsPIXEL      cf;
   amdmsCOMPL      retVal = amdmsSUCCESS;
 
-  nInputs = env->env.inFiles.nNames;
+  //nInputs = env->env.inFiles.nNames;
   nx = env->meanPixels[0].nx;
   ny = env->meanPixels[0].ny;
   for (i = 0; i < amdmsCONVERSION_FACTOR_FIT_NROWS; i++) {
@@ -1222,7 +1222,7 @@ amdmsCOMPL amdmsCalcDarkCurrent(amdmsALGO_PROPERTIES_ENV *env)
 amdmsCOMPL amdmsCalcHistogramForArea(amdmsALGO_PROPERTIES_ENV *env, int aoiX, int aoiY, int aoiWidth, int aoiHeight, int *inCount, int *outCount)
 {
   int          nx, ny, nz;
-  int          iPixel, nPixels;
+  int          iPixel;
   int          i, j, k;
   double       x, y;
   int          ix, iy;
@@ -1230,7 +1230,7 @@ amdmsCOMPL amdmsCalcHistogramForArea(amdmsALGO_PROPERTIES_ENV *env, int aoiX, in
   nz = env->env.inFiles.nNames;
   nx = env->meanPixels[0].nx;
   ny = env->meanPixels[0].ny;
-  nPixels = nx*ny;
+  //nPixels = nx*ny;
   for (j = 0; j < aoiHeight; j++) {
     iPixel = (j + aoiY)*nx + aoiX;
     for (i = 0; i < aoiWidth; i++) {
