@@ -79,7 +79,6 @@
 /*-----------------------------------------------------------------------------
                             Functions prototypes
  -----------------------------------------------------------------------------*/
-
 static int amber_ascii_export_create(cpl_plugin *) ;
 static int amber_ascii_export_exec(cpl_plugin *) ;
 static int amber_ascii_export_destroy(cpl_plugin *) ;
@@ -90,14 +89,7 @@ static int amber_ascii_export(cpl_parameterlist *, cpl_frameset *) ;
                             Static variables
  -----------------------------------------------------------------------------*/
 
-static struct {
-    /* Inputs */
-    int         bool_option ;
-    char        str_option[512] ; 
 
-    /* Outputs */
-    double      qc_param ;
-} amber_ascii_export_config ;
 
 static char amber_ascii_export_man[] =
 "This recipe exports data stored in an AMBER OI product into ASCII files, two export methods are present\n"
@@ -235,7 +227,6 @@ static int amber_ascii_export(
 {
  
   /* CPL structures */
-  cpl_frameset  * cur_set;
   cpl_frame     * cur_frame;
   cpl_parameter * cur_param; 
 
@@ -247,7 +238,6 @@ static int amber_ascii_export(
   char   szASCII2[1024];
   char   szASCII3[1024];
   char   szMethod[1024];
-  char   szCommand[1024];
   char   szBuffer[1024];
   char   szLine[4096];
   char   szRA[15];
@@ -268,22 +258,12 @@ static int amber_ascii_export(
 
   int  iStatus      = 0;
   int  iIsScience   = -1; /* neither SCIENCE or CALIB */   
-  int  base         = 0;
-  int  iInclude     = 0;
-  int  iSelFrame    = 0;
-  int  iAverage     = 0;
-  int  iFramesLeft  = 0;
-  int  iFrameIsGood = 0;
   int  iFrameCount  = 0;
-
-  double fThreshold = 0.F;
   
-  cur_set     = NULL;
   cur_frame   = NULL;
   pszFilename = NULL;
   pszFileTag  = NULL;
 
-  amdlibSELECTION selectedFrames;
   cpl_frameset_iterator * it = NULL;
   
   const char * fctid = "amber_ascii_export";
@@ -457,22 +437,11 @@ static int amber_ascii_export(
       
       /* Count Frames with Fringe SNR greater than xxx */
       int iFrame        = 0;  
-      int iFittingFrame = 0;  
-      double dLowSNR    = 99999999.9;
-      double dHighSNR   = 0;
-      double dFringeSNR = 0;
-      int    bFrameOK   = 0;
       int iFDate        = 0;
       int iFName        = 0;
 
-      /* Setup the default Options for Storing and Frame Selection */
-      amdlibCPT_VIS_OPTIONS visOptions = { 1, amdlibSTATISTICAL_ERROR, amdlibUNWRAPPED_PHASE, 
-	                                   1, amdlibNO_FRAME_SEL, fThreshold };
 
-      amdlibBAND band = amdlibK_BAND;
 
-      /* Test the band */
-      band = amdlibGetBand(wave.wlen[0]);
       
       /*
       if (amdlibGetBand(wave.wlen[wave.nbWlen-1]) != band)
@@ -554,7 +523,6 @@ static int amber_ascii_export(
     //  strcpy( szASCII, "/tmp/amber_export.txt" );
 
       /* Variables */
-      double fVisibility = 0;
       double fVisModul = 0;
       int    iTest = 0;
       int    iBase = 0;
