@@ -296,7 +296,7 @@ static int amber_trf(cpl_frameset * frameset, cpl_parameterlist * parlist)
 	}
 
 	for(i=0; i<frameset_orig_length; i++){
-		cur_frame=cpl_frameset_get_frame(frameset,i);
+		cur_frame=cpl_frameset_get_position(frameset,i);
 		if (!strcmp(cpl_frame_get_tag(cur_frame), "CALIB_REDUCED"))
 		{
 			amber_TransferFunction("amber_trf",
